#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hakyll
version:              4.16.4.0
visibility:           public
id:                   hakyll-4.16.4.0-5qZiDMXBVrJEgNdp8lYWFC
key:                  hakyll-4.16.4.0-5qZiDMXBVrJEgNdp8lYWFC
license:              BSD-3-Clause
maintainer:           Jasper Van der Jeugt <m@jaspervdj.be>
author:               Jasper Van der Jeugt <m@jaspervdj.be>
homepage:             http://jaspervdj.be/hakyll
synopsis:             A static website compiler library
description:
    Hakyll is a static website compiler library. It provides you with the tools to
    create a simple or advanced static website using a Haskell DSL and formats
    such as markdown or RST. You can find more information, including a tutorial,
    on the website:

    * <http://jaspervdj.be/hakyll>

    If you seek assistance, there'\''s:

    * A google group: <http://groups.google.com/group/hakyll>

    * An IRC channel, @#hakyll@ on irc.libera.chat (we *do not* have a channel on Freenode anymore)

    Additionally, there'\''s the Haddock documentation in the different modules,
    meant as a reference.

category:             Web
abi:                  b91751ecfe2c572591fa328741ca5892
exposed:              True
exposed-modules:
    Hakyll Hakyll.Commands Hakyll.Core.Compiler
    Hakyll.Core.Compiler.Internal Hakyll.Core.Configuration
    Hakyll.Core.Dependencies Hakyll.Core.File Hakyll.Core.Identifier
    Hakyll.Core.Identifier.Pattern Hakyll.Core.Item Hakyll.Core.Logger
    Hakyll.Core.Metadata Hakyll.Core.Provider
    Hakyll.Core.Provider.Metadata Hakyll.Core.Routes Hakyll.Core.Rules
    Hakyll.Core.Rules.Internal Hakyll.Core.Runtime Hakyll.Core.Store
    Hakyll.Core.UnixFilter Hakyll.Core.Util.File
    Hakyll.Core.Util.String Hakyll.Core.Writable Hakyll.Main
    Hakyll.Web.CompressCss Hakyll.Web.Feed Hakyll.Web.Html
    Hakyll.Web.Html.RelativizeUrls Hakyll.Web.Meta.JSONLD
    Hakyll.Web.Meta.OpenGraph Hakyll.Web.Meta.TwitterCard
    Hakyll.Web.Paginate Hakyll.Web.Pandoc Hakyll.Web.Pandoc.Biblio
    Hakyll.Web.Pandoc.FileType Hakyll.Web.Redirect Hakyll.Web.Tags
    Hakyll.Web.Template Hakyll.Web.Template.Context
    Hakyll.Web.Template.Internal Hakyll.Web.Template.Internal.Element
    Hakyll.Web.Template.Internal.Trim Hakyll.Web.Template.List

hidden-modules:
    Data.List.Extended Data.Yaml.Extended Hakyll.Check
    Hakyll.Core.Compiler.Require
    Hakyll.Core.Identifier.Pattern.Internal Hakyll.Core.Item.SomeItem
    Hakyll.Core.Provider.Internal Hakyll.Core.Provider.MetadataCache
    Hakyll.Core.Util.Parser Paths_hakyll Hakyll.Preview.Poll
    Hakyll.Preview.Server Hakyll.Web.Pandoc.Binary

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hakyll-4.16.4.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hakyll-4.16.4.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hakyll-4.16.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hakyll
hs-libraries:         HShakyll-4.16.4.0-5qZiDMXBVrJEgNdp8lYWFC
depends:
    aeson-2.2.2.0-5ic0qdnYZHH6zFYkxFCOtx base-4.18.2.1 binary-0.8.9.1
    blaze-html-0.9.2.0-GrDzB1jIZhp1oZYOXFcy0G bytestring-0.11.5.3
    containers-0.6.7 data-default-0.7.1.3-GWfmROYPtdX1tMV8eki8U8
    deepseq-1.4.8.1 directory-1.3.8.5
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz filepath-1.4.300.1
    fsnotify-0.4.4.0-33OmXoHw1QoDrttCymGbQb
    hashable-1.4.7.0-GIhdlNoQDSBAO6SjAK3pjT
    http-conduit-2.3.9.1-CJjQ4Pj4smCJ23yhm2qXQz
    http-types-0.12.4-CXiZJUbLhJFHeSLHvVo6Rt
    lrucache-1.2.0.1-34e4rU2OpGtGXjnvLtyFkI mtl-2.3.1
    network-uri-2.6.4.2-EKjXwcSJoi8IwfSCQFPAn2
    optparse-applicative-0.18.1.0-7SnpJ8KlnMr6TDIti6V1EO
    pandoc-3.6-LgrDP1ksXicHSdH79CflyZ parsec-3.1.16.1 process-1.6.19.0
    random-1.2.1.3-DsZJWYr04hc2YE8pqhZcvw
    regex-tdfa-1.3.2.5-5LmFHIFwXRgGzMBvrwvbhl
    resourcet-1.2.6-Eyr7bfOz5d6K4XSFfoBWea
    scientific-0.3.8.1-3ttkxdCo3DY31RbKExXamW
    tagsoup-0.14.8-i5MObb7WtI6cmvLhWD2aw template-haskell-2.20.0.0
    text-2.0.2 time-1.12.2
    time-locale-compat-0.1.1.5-8XUEctZKps57K6Zw5siYoh
    vector-0.13.2.0-DH6UT7zpR061zYDIVIbmaS
    wai-3.2.4-33aeOeERzkeGIF7OkDVW43
    wai-app-static-3.1.9-DUpZpceFXEa6XvsYBwZRTs
    warp-3.4.0-3cQ7FyihRHt3HbPBKLrLdw
    yaml-0.11.11.2-2VdKE2QkoLl3uA5EaDUwWO

haddock-interfaces:   /usr/share/doc/haskell-hakyll/html/hakyll.haddock
haddock-html:         /usr/share/doc/haskell-hakyll/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

